################################################################################
#
# Makefile  : Omega, web2c win32.mak makefile fragment to build Omega
# Author    : Fabrice Popineau <Fabrice.Popineau@supelec.fr>
# Platform  : Win32, Microsoft VC++ 6.0, depends upon fpTeX 0.5 sources
# Time-stamp: <02/10/23 18:29:44 popineau>
#
################################################################################

Makefile: $(win32make_srcdir)/omega.mak

omegaware_programs = $(objdir)\otangle.exe $(objdir)\odvicopy.exe $(objdir)\odvitype.exe

omega_programs = $(omega) $(otangle) $(odvicopy) $(odvitype) \
                 $(otps_programs) $(omegafonts_programs)

# The C sources.
omega_c = omega.c
omegaware_c = odvicopy.c odvitype.c otangle.c
omega_o = $(objdir)\omega.obj $(objdir)\omegafirst.obj $(objdir)\omegabis.obj

# Generation of the web and ch files.
odvicopy.web: omegaware\odvicopy.web
	-@$(del) $@
	$(copy) $(srcdir)\omegaware\odvicopy.web $@
odvicopy.ch: omegaware\odvicopy.ch
	-@$(del) $@
	$(copy) $(srcdir)\omegaware\odvicopy.ch $@
odvitype.web: omegaware\odvitype.web
	-@$(del) $@
	$(copy) $(srcdir)\omegaware\odvitype.web $@
odvitype.ch: omegaware\odvitype.ch
	-@$(del) $@
	$(copy) $(srcdir)\omegaware\odvitype.ch $@
omega.web: $(objdir)\tie.exe tex.web 
omega.web: omegadir/omnode.ch
omega.web: omegadir/om16bit.ch
omega.web: omegadir/omstr.ch
omega.web: omegadir/omfont.ch
omega.web: omegadir/omchar.ch
omega.web: omegadir/omfi.ch
omega.web: omegadir/ompar.ch
omega.web: omegadir/omocp.ch
omega.web: omegadir/omfilter.ch
omega.web: omegadir/omtrans.ch
omega.web: omegadir/omdir.ch
omega.web: omegadir/omxml.ch
	.\$(objdir)\tie -m omega.web tex.web \
	 omegadir/omnode.ch \
	 omegadir/om16bit.ch \
	 omegadir/omstr.ch \
	 omegadir/omfont.ch \
	 omegadir/omchar.ch \
	 omegadir/omfi.ch \
	 omegadir/ompar.ch \
	 omegadir/omocp.ch \
	 omegadir/omfilter.ch \
	 omegadir/omtrans.ch \
	 omegadir/omdir.ch \
	 omegadir/omxml.ch
omega.ch: $(objdir)\tie.exe omega.web
omega.ch: omegadir/comnode.ch
omega.ch: omegadir/com16bit.ch
omega.ch: omegadir/comstr.ch
omega.ch: omegadir/comfont.ch
omega.ch: omegadir/comchar.ch
omega.ch: omegadir/comfi.ch
omega.ch: omegadir/compar.ch
omega.ch: omegadir/comocp.ch
omega.ch: omegadir/comfilter.ch
omega.ch: omegadir/comtrans.ch
omega.ch: omegadir/comdir.ch
omega.ch: omegadir/comxml.ch
omega.ch: omegadir/comsrcspec.ch
	.\$(objdir)\tie -c omega.ch omega.web \
	omegadir/comnode.ch \
	omegadir/com16bit.ch \
	omegadir/comstr.ch \
	omegadir/comfont.ch \
	omegadir/comchar.ch \
	omegadir/comfi.ch \
	omegadir/compar.ch \
	omegadir/comocp.ch \
	omegadir/comfilter.ch \
	omegadir/comtrans.ch \
	omegadir/comdir.ch \
	omegadir/comxml.ch \
	omegadir/comsrcspec.ch
otangle.web: omegaware\otangle.web
	-@$(del) $@
	$(copy) $(srcdir)\omegaware\otangle.web $@
otangle.ch: omegaware\otangle.ch
	-@$(del) $@
	$(copy) $(srcdir)\omegaware\otangle.ch $@

# Three additional files
omegafirst.c: omegadir\omega.c 
	-@$(del) $@
	$(copy) $(srcdir)\omegadir\omega.c $@
	$(touch) $@
omegabis.c: omegadir\omegabis.c 
	-@$(del) $@
	$(copy) $(srcdir)\omegadir\omegabis.c $@
omegamem.h: omegadir\omegamem.h
	-@$(del) $@
	$(copy) $(srcdir)\omegadir\omegamem.h $@

# Some additional programs for Omega: the programs themselves are named
# in the variable otps_programs, defined above.
otps\$(objdir)\otp2ocp.exe otps\$(objdir)\outocp.exe:
	-@echo $(verbose) & ( \
		pushd otps & $(make) all & popd \
	)
omegafonts\$(objdir)\omfonts.exe:
	-@echo $(verbose) & ( \
		pushd omegafonts & $(make) all & popd \
	)

!if 0
install-omega: install-omega-exec install-omega-data
install-omega-exec:: install-omega-links
install-omega-data:: install-omega-dumps

# The actual binary executables and pool files.
install-omega-programs: $(omega_programs)
	$(SHELL) $(top_srcdir)/../mkinstalldirs $(bindir)
	for p in omega; do $(INSTALL_LIBTOOL_PROG) $(bindir) $$p; done
	cd otps && $(MAKE) $(install_makeargs) install-programs
	cd omegafonts && $(MAKE) $(install_makeargs) install-programs

# The links to {mf,mp,tex} for each format and for {ini,vir}{mf,mp,tex},
# plus the equivalents for e-TeX, Omega, pdfTeX, and pdfeTeX.
install-omega-links: install-omega-programs
	cd omegafonts && $(MAKE) $(install_makeargs) install-links
	cd $(bindir) && (rm -f iniomega viromega; \
	  $(LN) omega iniomega; $(LN) omega viromega)
# The ugly "" avoids a syntax error in case the lists are empty.
	test -z "$(ofmts)" || \
	  for f in ""$(ofmts); do base=`basename $$f .fmt`; \
	    (cd $(bindir) && (rm -f $$base; $(LN) omega $$base)); done

# Always do plain.*, so examples from the TeXbook (etc.) will work.
install-omega-dumps: install-omega-fmts
install-omega-fmts: ofmts
	$(SHELL) $(top_srcdir)/../mkinstalldirs $(fmtdir)
	test -z "$(all_ofmts)" || \
	  for f in ""$(all_ofmts); \
	    do $(INSTALL_DATA) $$f $(fmtdir)/$$f; done

# Auxiliary files.
install-omega-data::
	$(SHELL) $(top_srcdir)/../mkinstalldirs $(texpooldir) 
	$(INSTALL_DATA) omega.pool $(texpooldir)/omega.pool
	$(INSTALL_DATA) $(srcdir)/tiedir/tie.1 $(mandir)/tie.$(manext)
!endif

# end of omega.mak
#  
# Local variables:
# page-delimiter: "^# \f"
# mode: Makefile
# End:
